# Generated by Django 4.2.14 on 2024-10-18 10:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('messaging', '0003_modify_message_object_storage'),
    ]

    operations = [
        migrations.AlterField(
            model_name='topiccallback',
            name='protocol',
            field=models.CharField(choices=[('https', 'HTTPS'), ('http', 'HTTP'), ('email', 'Email'), ('lambda', 'AWS Lambda'), ('sqs', 'Amazon SQS')], default='https', max_length=32),
        ),
    ]
